@@ -161,15 +161,14 @@ def test_pep518_refuses_invalid_build_system(
     assert "pyproject.toml" in result.stderr
 
 
-@pytest.mark.network
 def test_pep518_allows_missing_requires(
-    script: PipTestEnvironment, data: TestData, common_wheels: Path
+    script: PipTestEnvironment, data: TestData
 ) -> None:
-    result = script.pip(
-        "install",
+    result = script.pip_install_local(
         "-f",
-        common_wheels,
-        data.src.joinpath("pep518_missing_requires"),
+        data.common_wheels,
+        data.src / "pep518_missing_requires",
+        build_isolation=True,
         expect_stderr=True,
     )
     # Make sure we don't warn when this occurs.
@@ -182,7 +181,6 @@ def test_pep518_allows_missing_requires(
     assert result.files_created
 
 
-@pytest.mark.network
 @pytest.mark.usefixtures("enable_user_site")
 def test_pep518_with_user_pip(
     script: PipTestEnvironment, pip_src: Path, data: TestData, common_wheels: Path
@@ -196,13 +194,12 @@ def test_pep518_with_user_pip(
     non-isolated environment, and break pip in the system site-packages,
     so that isolated uses of pip will fail.
     """
-    script.pip(
-        "install",
+    script.pip_install_local("flit-core", "-f", common_wheels)
+    script.pip_install_local(
         "--ignore-installed",
-        "-f",
-        common_wheels,
         "--user",
         pip_src,
+        build_isolation=False,
         # WARNING: The scripts pip, pip3, ... are installed in ... which is not on PATH
         allow_stderr_warning=True,
     )
@@ -222,8 +219,9 @@ def test_pep518_with_user_pip(
     )
 
 
+@pytest.mark.parametrize("flag", ["", "--use-feature=inprocess-build-deps"])
 def test_pep518_with_extra_and_markers(
-    script: PipTestEnvironment, data: TestData, common_wheels: Path
+    script: PipTestEnvironment, data: TestData, common_wheels: Path, flag: str
 ) -> None:
     script.pip(
         "wheel",
@@ -233,11 +231,13 @@ def test_pep518_with_extra_and_markers(
         "-f",
         data.find_links,
         data.src.joinpath("pep518_with_extra_and_markers-1.0"),
+        flag,
     )
 
 
+@pytest.mark.parametrize("flag", ["", "--use-feature=inprocess-build-deps"])
 def test_pep518_with_namespace_package(
-    script: PipTestEnvironment, data: TestData, common_wheels: Path
+    script: PipTestEnvironment, data: TestData, common_wheels: Path, flag: str
 ) -> None:
     script.pip(
         "wheel",
@@ -247,6 +247,7 @@ def test_pep518_with_namespace_package(
         "-f",
         data.find_links,
         data.src.joinpath("pep518_with_namespace_package-1.0"),
+        flag,
         use_module=True,
     )
 
@@ -256,12 +257,14 @@ def test_pep518_with_namespace_package(
     "package",
     ["pep518_forkbomb", "pep518_twin_forkbombs_first", "pep518_twin_forkbombs_second"],
 )
+@pytest.mark.parametrize("flag", ["", "--use-feature=inprocess-build-deps"])
 def test_pep518_forkbombs(
     script: PipTestEnvironment,
     data: TestData,
     common_wheels: Path,
     command: str,
     package: str,
+    flag: str,
 ) -> None:
     package_source = next(data.packages.glob(package + "-[0-9]*.tar.gz"))
     result = script.pip(
@@ -273,6 +276,7 @@ def test_pep518_forkbombs(
         "-f",
         data.find_links,
         package,
+        flag,
         expect_error=True,
     )
     assert (
@@ -284,7 +288,6 @@ def test_pep518_forkbombs(
     ), str(result)
 
 
-@pytest.mark.network
 def test_pip_second_command_line_interface_works(
     script: PipTestEnvironment,
     pip_src: Path,
@@ -298,11 +301,11 @@ def test_pip_second_command_line_interface_works(
     # Re-install pip so we get the launchers.
     script.pip("install", "--no-index", "-f", common_wheels, pip_src)
     args = [f"pip{pyversion}"]
-    args.extend(["install", "INITools==0.2"])
-    args.extend(["-f", os.fspath(data.packages)])
+    args.extend(["install", "simplewheel==2.0"])
+    args.extend(["-f", str(data.packages), "--no-index"])
     result = script.run(*args)
-    dist_info_folder = script.site_packages / "initools-0.2.dist-info"
-    initools_folder = script.site_packages / "initools"
+    dist_info_folder = script.site_packages / "simplewheel-2.0.dist-info"
+    initools_folder = script.site_packages / "simplewheel"
     result.did_create(dist_info_folder)
     result.did_create(initools_folder)
 
@@ -955,7 +958,7 @@ def test_install_pre__setup_requires_with_pyproject(
     pyproject_path = local_dir.joinpath("pyproject.toml")
     pyproject_path.write_text(
         "[build-system]\n"
-        f'requires = ["setuptools", "wheel", "{depends_package}"]\n'
+        f'requires = ["setuptools", "{depends_package}"]\n'
         'build-backend = "setuptools.build_meta"\n'
     )
     setup_py_path = local_dir.joinpath("setup.py")
@@ -1025,14 +1028,15 @@ def test_install_with_hacked_egg_info(
     assert "Successfully installed hackedegginfo-0.0.0\n" in result.stdout
 
 
-@pytest.mark.network
-def test_install_package_with_same_name_in_curdir(script: PipTestEnvironment) -> None:
+def test_install_package_with_same_name_in_curdir(
+    script: PipTestEnvironment, data: TestData
+) -> None:
     """
     Test installing a package with the same name of a local folder
     """
-    script.scratch_path.joinpath("mock==0.6").mkdir()
-    result = script.pip("install", "mock==0.6")
-    dist_info_folder = script.site_packages / "mock-0.6.0.dist-info"
+    script.scratch_path.joinpath("six==1.17.0").mkdir()
+    result = script.pip_install_local("six==1.17.0", "-f", data.pypi_packages)
+    dist_info_folder = script.site_packages / "six-1.17.0.dist-info"
     result.did_create(dist_info_folder)
 
 
@@ -1081,14 +1085,17 @@ def test_install_folder_using_relative_path(script: PipTestEnvironment) -> None:
     result.did_create(dist_info_folder)
 
 
-@pytest.mark.network
-def test_install_package_which_contains_dev_in_name(script: PipTestEnvironment) -> None:
+def test_install_package_which_contains_dev_in_name(
+    script: PipTestEnvironment, data: TestData
+) -> None:
     """
     Test installing package from PyPI which contains 'dev' in name
     """
-    result = script.pip("install", "django-devserver==0.0.4")
+    result = script.pip_install_local(
+        "django_devserver==0.8.0", "-f", data.pypi_packages
+    )
     devserver_folder = script.site_packages / "devserver"
-    dist_info_folder = script.site_packages / "django_devserver-0.0.4.dist-info"
+    dist_info_folder = script.site_packages / "django_devserver-0.8.0.dist-info"
     result.did_create(devserver_folder)
     result.did_create(dist_info_folder)
 
@@ -1363,7 +1370,6 @@ def _test_install_editable_with_prefix(
     return result
 
 
-@pytest.mark.network
 def test_install_editable_with_target(script: PipTestEnvironment) -> None:
     pkg_path = script.scratch_path / "pkg"
     pkg_path.mkdir()
@@ -1373,7 +1379,7 @@ def test_install_editable_with_target(script: PipTestEnvironment) -> None:
         from setuptools import setup
         setup(
             name='pkg',
-            install_requires=['watching_testrunner']
+            install_requires=['simplewheel==2.0']
         )
     """
         )
@@ -1381,14 +1387,14 @@ def test_install_editable_with_target(script: PipTestEnvironment) -> None:
 
     target = script.scratch_path / "target"
     target.mkdir()
-    result = script.pip("install", "--editable", pkg_path, "--target", target)
+    result = script.pip_install_local("-e", pkg_path, "--target", target)
 
     direct_url_path = result.get_created_direct_url_path("pkg")
     assert direct_url_path
     assert direct_url_path.parent.parent == target
     direct_url = DirectUrl.from_json(direct_url_path.read_text())
     assert direct_url.is_local_editable()
-    result.did_create(script.scratch / "target" / "watching_testrunner.py")
+    result.did_create(script.scratch / "target" / "simplewheel" / "__init__.py")
 
 
 def test_install_editable_with_prefix_setup_py(script: PipTestEnvironment) -> None:
@@ -1576,13 +1582,14 @@ def test_url_incorrect_case_file_index(
     assert "Looking in links: " not in result.stdout
 
 
-@pytest.mark.network
-def test_compiles_pyc(script: PipTestEnvironment) -> None:
+def test_compiles_pyc(script: PipTestEnvironment, data: TestData) -> None:
     """
     Test installing with --compile on
     """
     del script.environ["PYTHONDONTWRITEBYTECODE"]
-    script.pip("install", "--compile", "--no-binary=:all:", "INITools==0.2")
+    script.pip_install_local(
+        "--compile", "--no-binary=:all:", "INITools==0.2", "-f", data.pypi_packages
+    )
 
     # There are many locations for the __init__.pyc file so attempt to find
     #   any of them
@@ -1594,13 +1601,14 @@ def test_compiles_pyc(script: PipTestEnvironment) -> None:
     assert any(exists)
 
 
-@pytest.mark.network
-def test_no_compiles_pyc(script: PipTestEnvironment) -> None:
+def test_no_compiles_pyc(script: PipTestEnvironment, data: TestData) -> None:
     """
     Test installing from wheel with --compile on
     """
     del script.environ["PYTHONDONTWRITEBYTECODE"]
-    script.pip("install", "--no-compile", "--no-binary=:all:", "INITools==0.2")
+    script.pip_install_local(
+        "--no-compile", "--no-binary=:all:", "INITools==0.2", "-f", data.pypi_packages
+    )
 
     # There are many locations for the __init__.pyc file so attempt to find
     #   any of them
@@ -1786,12 +1794,13 @@ def test_install_no_binary_builds_wheels(
     assert "Failed to build wheelbroken" in str(res), str(res)
 
 
-@pytest.mark.network
+@pytest.mark.parametrize("flag", ["", "--use-feature=inprocess-build-deps"])
 def test_install_no_binary_builds_pep_517_wheel(
-    script: PipTestEnvironment, data: TestData
+    script: PipTestEnvironment, data: TestData, flag: str
 ) -> None:
-    to_install = data.packages.joinpath("pep517_setup_and_pyproject")
-    res = script.pip("install", "--no-binary=:all:", "-f", data.find_links, to_install)
+    res = script.pip_install_local(
+        "--no-binary=:all:", data.packages / "pep517_setup_and_pyproject", flag
+    )
     expected = "Successfully installed pep517-setup-and-pyproject"
     # Must have installed the package
     assert expected in str(res), str(res)
@@ -1799,13 +1808,13 @@ def test_install_no_binary_builds_pep_517_wheel(
     assert "Building wheel for pep517-setup" in str(res), str(res)
 
 
-@pytest.mark.network
+@pytest.mark.parametrize("flag", ["", "--use-feature=inprocess-build-deps"])
 def test_install_no_binary_uses_local_backend(
-    script: PipTestEnvironment, data: TestData, tmpdir: Path
+    script: PipTestEnvironment, data: TestData, tmpdir: Path, flag: str
 ) -> None:
     to_install = data.packages.joinpath("pep517_wrapper_buildsys")
     script.environ["PIP_TEST_MARKER_FILE"] = marker = str(tmpdir / "marker")
-    res = script.pip("install", "--no-binary=:all:", "-f", data.find_links, to_install)
+    res = script.pip_install_local("--no-binary=:all:", to_install, flag)
     expected = "Successfully installed pep517-wrapper-buildsys"
     # Must have installed the package
     assert expected in str(res), str(res)
@@ -1813,8 +1822,9 @@ def test_install_no_binary_uses_local_backend(
     assert os.path.isfile(marker), "Local PEP 517 backend not used"
 
 
+@pytest.mark.parametrize("flag", ["", "--use-feature=inprocess-build-deps"])
 def test_install_no_binary_uses_cached_wheels(
-    script: PipTestEnvironment, data: TestData
+    script: PipTestEnvironment, data: TestData, flag: str
 ) -> None:
     # Seed the cache
     script.pip(
@@ -1829,6 +1839,7 @@ def test_install_no_binary_uses_cached_wheels(
         "-f",
         data.find_links,
         "upper",
+        flag,
         expect_stderr=True,
     )
     assert "Successfully installed upper-2.0" in str(res), str(res)
@@ -1899,22 +1910,22 @@ def test_double_install(script: PipTestEnvironment) -> None:
     assert msg not in result.stderr
 
 
-@pytest.mark.network
 def test_double_install_fail(
-    script: PipTestEnvironment, resolver_variant: ResolverVariant
+    script: PipTestEnvironment, data: TestData, resolver_variant: ResolverVariant
 ) -> None:
     """
     Test double install failing with two different version requirements
     """
-    result = script.pip(
-        "install",
-        "pip==7.*",
-        "pip==7.1.2",
+    # TODO: remove with the legacy resolver
+    result = script.pip_install_local(
+        "six==1.*",
+        "six==1.17.0",
+        find_links=data.pypi_packages,
         # The new resolver is perfectly capable of handling this
         expect_error=(resolver_variant == "legacy"),
     )
     if resolver_variant == "legacy":
-        msg = "Double requirement given: pip==7.1.2 (already in pip==7.*, name='pip')"
+        msg = "Double requirement given: six==1.17.0 (already in pip==0.*, name='pip')"
         assert msg in result.stderr
 
 
@@ -2055,7 +2066,7 @@ def test_install_from_test_pypi_with_ext_url_dep_is_blocked(
         "which are not also hosted on PyPI."
     )
     error_cause = (
-        "pep-508-url-deps depends on sampleproject@ "
+        "pep-508-url-deps depends on sampleproject @ "
         "https://github.com/pypa/sampleproject/archive/master.zip"
     )
     assert res.returncode == 1
@@ -2360,9 +2371,8 @@ def test_install_sends_client_cert(
     data: TestData,
 ) -> None:
     cert_path = cert_factory()
-    ctx = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
+    ctx = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH, cafile=cert_path)
     ctx.load_cert_chain(cert_path, cert_path)
-    ctx.load_verify_locations(cafile=cert_path)
     ctx.verify_mode = ssl.CERT_REQUIRED
 
     server = make_mock_server(ssl_context=ctx)
@@ -2402,16 +2412,17 @@ def test_install_sends_client_cert(
         assert environ["SSL_CLIENT_CERT"]
 
 
+@pytest.mark.parametrize("flag", ["", "--use-feature=inprocess-build-deps"])
 def test_install_sends_certs_for_pep518_deps(
     script: PipTestEnvironment,
     cert_factory: CertFactory,
     data: TestData,
     common_wheels: Path,
+    flag: str,
 ) -> None:
     cert_path = cert_factory()
-    ctx = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
+    ctx = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH, cafile=cert_path)
     ctx.load_cert_chain(cert_path, cert_path)
-    ctx.load_verify_locations(cafile=cert_path)
     ctx.verify_mode = ssl.CERT_REQUIRED
 
     setuptools_pkg = next(common_wheels.glob("setuptools*")).name
@@ -2422,7 +2433,7 @@ def test_install_sends_certs_for_pep518_deps(
     ]
     url = f"https://{server.host}:{server.port}/simple"
 
-    args = ["install", str(data.packages / "pep517_setup_and_pyproject")]
+    args = ["install", str(data.packages / "pep517_setup_and_pyproject"), flag]
     args.extend(["--index-url", url])
     args.extend(["--cert", cert_path, "--client-cert", cert_path])
 
@@ -2434,7 +2445,6 @@ def test_install_sends_certs_for_pep518_deps(
         assert environ.get("SSL_CLIENT_CERT", "")
 
 
-@pytest.mark.network
 def test_install_skip_work_dir_pkg(script: PipTestEnvironment, data: TestData) -> None:
     """
     Test that install of a package in working directory
@@ -2444,16 +2454,13 @@ def test_install_skip_work_dir_pkg(script: PipTestEnvironment, data: TestData) -
 
     # Create a test package, install it and then uninstall it
     pkg_path = create_test_package_with_setup(script, name="simple", version="1.0")
-    script.pip("install", "-e", ".", expect_stderr=True, cwd=pkg_path)
+    script.pip_install_local("-e", ".", expect_stderr=True, cwd=pkg_path)
 
     script.pip("uninstall", "simple", "-y")
 
     # Running the install command again from the working directory
     # will install the package as it was uninstalled earlier
-    result = script.pip(
-        "install",
-        "--find-links",
-        data.find_links,
+    result = script.pip_install_local(
         "simple",
         expect_stderr=True,
         cwd=pkg_path,
@@ -2694,8 +2701,9 @@ def test_install_pip_prints_req_chain_pypi(script: PipTestEnvironment) -> None:
 
 
 @pytest.mark.parametrize("common_prefix", ["", "linktest-1.0/"])
-@pytest.mark.network
-def test_install_sdist_links(script: PipTestEnvironment, common_prefix: str) -> None:
+def test_install_sdist_links(
+    script: PipTestEnvironment, data: TestData, common_prefix: str
+) -> None:
     """
     Test installing an sdist with hard and symbolic links.
     """
@@ -2809,7 +2817,7 @@ def test_install_sdist_links(script: PipTestEnvironment, common_prefix: str) ->
     print(result)
 
     # Install the package
-    result = script.pip("install", str(sdist_path))
+    result = script.pip_install_local(sdist_path)
     print(result)
 
     # Show installed content, for debugging the test
