@@ -1,8 +1,6 @@
-"""Provides helper classes for testing option handling in pip
-"""
+"""Provides helper classes for testing option handling in pip"""
 
 from optparse import Values
-from typing import List, Tuple
 
 from pip._internal.cli import cmdoptions
 from pip._internal.cli.base_command import Command
@@ -11,8 +9,8 @@ from pip._internal.commands import CommandInfo, commands_dict
 
 class FakeCommand(Command):
     def main(  # type: ignore[override]
-        self, args: List[str]
-    ) -> Tuple[Values, List[str]]:
+        self, args: list[str]
+    ) -> tuple[Values, list[str]]:
         index_opts = cmdoptions.make_option_group(
             cmdoptions.index_group,
             self.parser,
@@ -22,12 +20,12 @@ class FakeCommand(Command):
 
 
 class AddFakeCommandMixin:
-    def setup(self) -> None:
+    def setup_method(self) -> None:
         commands_dict["fake"] = CommandInfo(
             "tests.lib.options_helpers",
             "FakeCommand",
             "fake summary",
         )
 
-    def teardown(self) -> None:
+    def teardown_method(self) -> None:
         commands_dict.pop("fake")
