@@ -4,7 +4,7 @@ from pip._vendor.packaging.tags import Tag
 
 from pip._internal.exceptions import InvalidWheelFilename
 from pip._internal.models.wheel import Wheel
-from pip._internal.utils import compatibility_tags, deprecation
+from pip._internal.utils import compatibility_tags
 
 
 class TestWheelFile:
@@ -12,17 +12,24 @@ class TestWheelFile:
         w = Wheel("simple-1.1.1-py2-none-any.whl")
         assert w.name == "simple"
         assert w.version == "1.1.1"
-        assert w.pyversions == ["py2"]
-        assert w.abis == ["none"]
-        assert w.plats == ["any"]
+        assert w.build_tag == ()
+        assert w.file_tags == frozenset(
+            [Tag(interpreter="py2", abi="none", platform="any")]
+        )
 
     def test_wheel_pattern_multi_values(self) -> None:
         w = Wheel("simple-1.1-py2.py3-abi1.abi2-any.whl")
         assert w.name == "simple"
         assert w.version == "1.1"
-        assert w.pyversions == ["py2", "py3"]
-        assert w.abis == ["abi1", "abi2"]
-        assert w.plats == ["any"]
+        assert w.build_tag == ()
+        assert w.file_tags == frozenset(
+            [
+                Tag(interpreter="py2", abi="abi1", platform="any"),
+                Tag(interpreter="py2", abi="abi2", platform="any"),
+                Tag(interpreter="py3", abi="abi1", platform="any"),
+                Tag(interpreter="py3", abi="abi2", platform="any"),
+            ]
+        )
 
     def test_wheel_with_build_tag(self) -> None:
         # pip doesn't do anything with build tags, but theoretically, we might
@@ -30,17 +37,18 @@ class TestWheelFile:
         w = Wheel("simple-1.1-4-py2-none-any.whl")
         assert w.name == "simple"
         assert w.version == "1.1"
-        assert w.pyversions == ["py2"]
-        assert w.abis == ["none"]
-        assert w.plats == ["any"]
+        assert w.build_tag == (4, "")
+        assert w.file_tags == frozenset(
+            [Tag(interpreter="py2", abi="none", platform="any")]
+        )
 
     def test_single_digit_version(self) -> None:
         w = Wheel("simple-1-py2-none-any.whl")
         assert w.version == "1"
 
     def test_non_pep440_version(self) -> None:
-        w = Wheel("simple-_invalid_-py2-none-any.whl")
-        assert w.version == "-invalid-"
+        with pytest.raises(InvalidWheelFilename):
+            Wheel("simple-_invalid_-py2-none-any.whl")
 
     def test_missing_version_raises(self) -> None:
         with pytest.raises(InvalidWheelFilename):
@@ -171,6 +179,56 @@ class TestWheelFile:
         w = Wheel("simple-0.1-cp313-none-ios_15_1_arm64_iphoneos.whl")
         assert not w.supported(tags=tags)
 
+    def test_android(self) -> None:
+        arm_old = compatibility_tags.get_supported(
+            "313", platforms=["android_21_arm64_v8a"], impl="cp"
+        )
+        arm_new = compatibility_tags.get_supported(
+            "313", platforms=["android_30_arm64_v8a"], impl="cp"
+        )
+        x86_old = compatibility_tags.get_supported(
+            "313", platforms=["android_21_x86_64"], impl="cp"
+        )
+        x86_new = compatibility_tags.get_supported(
+            "313", platforms=["android_30_x86_64"], impl="cp"
+        )
+
+        w = Wheel("simple-0.1-cp313-none-android_21_arm64_v8a.whl")
+        assert w.supported(arm_old)
+        assert w.supported(arm_new)
+        assert not w.supported(x86_old)
+        assert not w.supported(x86_new)
+
+        w = Wheel("simple-0.1-cp313-none-android_22_arm64_v8a.whl")
+        assert not w.supported(arm_old)
+        assert w.supported(arm_new)
+        assert not w.supported(x86_old)
+        assert not w.supported(x86_new)
+
+        w = Wheel("simple-0.1-cp313-none-android_31_arm64_v8a.whl")
+        assert not w.supported(arm_old)
+        assert not w.supported(arm_new)
+        assert not w.supported(x86_old)
+        assert not w.supported(x86_new)
+
+        w = Wheel("simple-0.1-cp313-none-android_20_x86_64.whl")
+        assert not w.supported(arm_old)
+        assert not w.supported(arm_new)
+        assert w.supported(x86_old)
+        assert w.supported(x86_new)
+
+        w = Wheel("simple-0.1-cp313-none-android_30_x86_64.whl")
+        assert not w.supported(arm_old)
+        assert not w.supported(arm_new)
+        assert not w.supported(x86_old)
+        assert w.supported(x86_new)
+
+        w = Wheel("simple-0.1-cp313-none-android_31_x86_64.whl")
+        assert not w.supported(arm_old)
+        assert not w.supported(arm_new)
+        assert not w.supported(x86_old)
+        assert not w.supported(x86_new)
+
     def test_support_index_min(self) -> None:
         """
         Test results from `support_index_min`
@@ -195,16 +253,14 @@ class TestWheelFile:
 
     def test_version_underscore_conversion(self) -> None:
         """
-        Test that we convert '_' to '-' for versions parsed out of wheel
-        filenames
+        Test that underscore versions are now invalid (no longer converted)
         """
-        with pytest.warns(deprecation.PipDeprecationWarning):
-            w = Wheel("simple-0.1_1-py2-none-any.whl")
-        assert w.version == "0.1-1"
+        with pytest.raises(InvalidWheelFilename):
+            Wheel("simple-0.1_1-py2-none-any.whl")
 
-    def test_invalid_wheel_warning(self) -> None:
+    def test_invalid_wheel_raises(self) -> None:
         """
-        Test that wheel with invalid name produces warning
+        Test that wheel with invalid name now raises exception
         """
-        with pytest.warns(deprecation.PipDeprecationWarning):
+        with pytest.raises(InvalidWheelFilename):
             Wheel("six-1.16.0_build1-py3-none-any.whl")
