@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import itertools
 import os
 import stat
 import tempfile
+from collections.abc import Iterator
 from pathlib import Path
-from typing import Any, Iterator, Optional, Union
+from typing import Any
 from unittest import mock
 
 import pytest
@@ -233,9 +236,7 @@ not_deleted_kind = "not-deleted"
         (False, "unspecified", True),
     ],
 )
-def test_tempdir_registry(
-    delete: Union[bool, _Default], kind: str, exists: bool
-) -> None:
+def test_tempdir_registry(delete: bool | _Default, kind: str, exists: bool) -> None:
     with tempdir_registry() as registry:
         registry.set_delete(deleted_kind, True)
         registry.set_delete(not_deleted_kind, False)
@@ -248,7 +249,7 @@ def test_tempdir_registry(
 
 @pytest.mark.parametrize("delete,exists", [(_default, True), (None, False)])
 def test_temp_dir_does_not_delete_explicit_paths_by_default(
-    tmpdir: Path, delete: Optional[_Default], exists: bool
+    tmpdir: Path, delete: _Default | None, exists: bool
 ) -> None:
     p = tmpdir / "example"
     p.mkdir()
