@@ -4,7 +4,7 @@ import logging
 import os
 import pathlib
 from typing import Any
-from unittest import TestCase, mock
+from unittest import mock
 
 import pytest
 
@@ -52,6 +52,11 @@ def test_ensure_svn_available() -> None:
             ("git+https://example.com/pkg", "dev", "zope-interface"),
             "git+https://example.com/pkg@dev#egg=zope_interface",
         ),
+        # Test a revision with special characters.
+        (
+            ("git+https://example.com/pkg", "dev@1#2", "myproj"),
+            "git+https://example.com/pkg@dev%401%232#egg=myproj",
+        ),
     ],
 )
 def test_make_vcs_requirement_url(args: tuple[Any, ...], expected: str) -> None:
@@ -394,6 +399,11 @@ def test_git__get_url_rev__idempotent() -> None:
             "svn+https://svn.example.com/My+Project",
             ("https://svn.example.com/My+Project", None, (None, None)),
         ),
+        # Test percent-encoded characters in revision.
+        (
+            "svn+https://svn.example.com/MyProject@dev%401%232",
+            ("https://svn.example.com/MyProject", "dev@1#2", (None, None)),
+        ),
     ],
 )
 def test_version_control__get_url_rev_and_auth(
@@ -765,22 +775,30 @@ def test_subversion__get_remote_call_options(
     assert svn.get_remote_call_options() == expected_options
 
 
-class TestBazaarArgs(TestCase):
-    def setUp(self) -> None:
-        patcher = mock.patch("pip._internal.vcs.versioncontrol.call_subprocess")
-        self.addCleanup(patcher.stop)
-        self.call_subprocess_mock = patcher.start()
+class _TestVcsArgs:
+    @pytest.fixture(autouse=True)
+    def setup_base(
+        self, monkeypatch: pytest.MonkeyPatch, tmp_path: pathlib.Path
+    ) -> None:
+        self.dest = os.fspath(tmp_path / "dest")
+        self.call_subprocess_mock = mock.MagicMock()
+        monkeypatch.setattr(
+            "pip._internal.vcs.versioncontrol.call_subprocess",
+            self.call_subprocess_mock,
+        )
 
+    def assert_call_args(self, args: CommandArgs) -> None:
+        assert self.call_subprocess_mock.call_args[0][0] == args
+
+
+class TestBazaarArgs(_TestVcsArgs):
+    def setup_method(self) -> None:
         # Test Data.
         self.url = "bzr+http://username:password@bzr.example.com/"
         # use_interactive is set to False to test that remote call options are
         # properly added.
         self.svn = Bazaar()
         self.rev_options = RevOptions(Bazaar)
-        self.dest = "/tmp/test"
-
-    def assert_call_args(self, args: CommandArgs) -> None:
-        assert self.call_subprocess_mock.call_args[0][0] == args
 
     def test_fetch_new(self) -> None:
         self.svn.fetch_new(self.dest, hide_url(self.url), self.rev_options, verbosity=1)
@@ -790,7 +808,7 @@ class TestBazaarArgs(TestCase):
                 "checkout",
                 "--lightweight",
                 hide_url("bzr+http://username:password@bzr.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -803,7 +821,7 @@ class TestBazaarArgs(TestCase):
                 "--lightweight",
                 "--quiet",
                 hide_url("bzr+http://username:password@bzr.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -816,7 +834,7 @@ class TestBazaarArgs(TestCase):
                 "--lightweight",
                 "-vv",
                 hide_url("bzr+http://username:password@bzr.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -840,17 +858,12 @@ class TestBazaarArgs(TestCase):
         )
 
 
-class TestGitArgs(TestCase):
-    def setUp(self) -> None:
-        patcher = mock.patch("pip._internal.vcs.versioncontrol.call_subprocess")
-        self.addCleanup(patcher.stop)
-        self.call_subprocess_mock = patcher.start()
-
+class TestGitArgs(_TestVcsArgs):
+    def setup_method(self) -> None:
         # Test Data.
         self.url = "git+http://username:password@git.example.com/"
         self.svn = Git()
         self.rev_options = RevOptions(Git)
-        self.dest = "/tmp/test"
 
     def test_fetch_new(self) -> None:
         with mock.patch.object(self.svn, "get_git_version", return_value=(2, 17)):
@@ -866,7 +879,7 @@ class TestGitArgs(TestCase):
             "clone",
             "--filter=blob:none",
             hide_url("git+http://username:password@git.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         update_submodules_mock.assert_called_with(self.dest, verbosity=1)
@@ -884,7 +897,7 @@ class TestGitArgs(TestCase):
             "git",
             "clone",
             hide_url("git+http://username:password@git.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         update_submodules_mock.assert_called_with(self.dest, verbosity=1)
@@ -903,7 +916,7 @@ class TestGitArgs(TestCase):
             "clone",
             "--quiet",
             hide_url("git+http://username:password@git.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         update_submodules_mock.assert_called_with(self.dest, verbosity=0)
@@ -923,7 +936,7 @@ class TestGitArgs(TestCase):
             "--filter=blob:none",
             "--quiet",
             hide_url("git+http://username:password@git.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         update_submodules_mock.assert_called_with(self.dest, verbosity=0)
@@ -1056,17 +1069,12 @@ class TestGitArgs(TestCase):
         update_submodules_mock.assert_called_with(self.dest, verbosity=0)
 
 
-class TestMercurialArgs(TestCase):
-    def setUp(self) -> None:
-        patcher = mock.patch("pip._internal.vcs.versioncontrol.call_subprocess")
-        self.addCleanup(patcher.stop)
-        self.call_subprocess_mock = patcher.start()
-
+class TestMercurialArgs(_TestVcsArgs):
+    def setup_method(self) -> None:
         # Test Data.
         self.url = "hg+http://username:password@hg.example.com/"
         self.svn = Mercurial()
         self.rev_options = RevOptions(Mercurial)
-        self.dest = "/tmp/test"
 
     def test_fetch_new(self) -> None:
         self.svn.fetch_new(self.dest, hide_url(self.url), self.rev_options, verbosity=1)
@@ -1076,7 +1084,7 @@ class TestMercurialArgs(TestCase):
             "clone",
             "--noupdate",
             hide_url("hg+http://username:password@hg.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         assert self.call_subprocess_mock.call_args_list[1][0][0] == [
@@ -1093,7 +1101,7 @@ class TestMercurialArgs(TestCase):
             "--noupdate",
             "--quiet",
             hide_url("hg+http://username:password@hg.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         assert self.call_subprocess_mock.call_args_list[1][0][0] == [
@@ -1111,7 +1119,7 @@ class TestMercurialArgs(TestCase):
             "--noupdate",
             "--verbose",
             hide_url("hg+http://username:password@hg.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         assert self.call_subprocess_mock.call_args_list[1][0][0] == [
@@ -1130,7 +1138,7 @@ class TestMercurialArgs(TestCase):
             "--verbose",
             "--debug",
             hide_url("hg+http://username:password@hg.example.com/"),
-            "/tmp/test",
+            self.dest,
         ]
 
         assert self.call_subprocess_mock.call_args_list[1][0][0] == [
@@ -1169,22 +1177,14 @@ class TestMercurialArgs(TestCase):
         ]
 
 
-class TestSubversionArgs(TestCase):
-    def setUp(self) -> None:
-        patcher = mock.patch("pip._internal.vcs.versioncontrol.call_subprocess")
-        self.addCleanup(patcher.stop)
-        self.call_subprocess_mock = patcher.start()
-
+class TestSubversionArgs(_TestVcsArgs):
+    def setup_method(self) -> None:
         # Test Data.
         self.url = "svn+http://username:password@svn.example.com/"
         # use_interactive is set to False to test that remote call options are
         # properly added.
         self.svn = Subversion(use_interactive=False)
         self.rev_options = RevOptions(Subversion)
-        self.dest = "/tmp/test"
-
-    def assert_call_args(self, args: CommandArgs) -> None:
-        assert self.call_subprocess_mock.call_args[0][0] == args
 
     def test_obtain(self) -> None:
         self.svn.obtain(self.dest, hide_url(self.url), verbosity=1)
@@ -1198,7 +1198,7 @@ class TestSubversionArgs(TestCase):
                 "--password",
                 hide_value("password"),
                 hide_url("http://svn.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -1215,7 +1215,7 @@ class TestSubversionArgs(TestCase):
                 "--password",
                 hide_value("password"),
                 hide_url("http://svn.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -1227,7 +1227,7 @@ class TestSubversionArgs(TestCase):
                 "checkout",
                 "--non-interactive",
                 hide_url("svn+http://username:password@svn.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -1240,7 +1240,7 @@ class TestSubversionArgs(TestCase):
                 "--quiet",
                 "--non-interactive",
                 hide_url("svn+http://username:password@svn.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -1255,7 +1255,7 @@ class TestSubversionArgs(TestCase):
                 "-r",
                 "123",
                 hide_url("svn+http://username:password@svn.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -1271,7 +1271,7 @@ class TestSubversionArgs(TestCase):
                 "-r",
                 "123",
                 hide_url("svn+http://username:password@svn.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -1283,7 +1283,7 @@ class TestSubversionArgs(TestCase):
                 "switch",
                 "--non-interactive",
                 hide_url("svn+http://username:password@svn.example.com/"),
-                "/tmp/test",
+                self.dest,
             ]
         )
 
@@ -1294,6 +1294,6 @@ class TestSubversionArgs(TestCase):
                 "svn",
                 "update",
                 "--non-interactive",
-                "/tmp/test",
+                self.dest,
             ]
         )
